Index: pkg/mqtt/publish-sample.dart |
diff --git a/pkg/mqtt/publish-sample.dart b/pkg/mqtt/publish-sample.dart |
index 245a0aff0add15c7e27c944a8a41db71a2574c84..c0fc2726eb65c8b7853e53d500fae554f56f57a9 100644 |
--- a/pkg/mqtt/publish-sample.dart |
+++ b/pkg/mqtt/publish-sample.dart |
@@ -1,11 +1,11 @@ |
-import 'dart:fletch'; |
+import 'dart:dartino'; |
import 'package:mqtt/mqtt.dart'; |
// Sample code for publishing messages. |
// |
// For an end-to-end sample, first run subscribe-sample.dart, and then start |
// this program next to see the communication between the two. Note that this |
// program has to be started in a second session, e.g. `fletch start |
// publish-sample.dart in session 2'. |
void main() { |
// Create MQTT client. |
@@ -1,11 +1,11 @@ |
// For an end-to-end sample, first run subscribe-sample.dart, and then start |
// this program next to see the communication between the two. Note that this |
-// program has to be started in a second session, e.g. `fletch start |
+// program has to be started in a second session, e.g. `dartino start |
// publish-sample.dart in session 2'. |
void main() { |